##  Tag-Based Permissions
In the Tag-based Permissions section, you can configure permissions for specific attributes on fact sheets with a specific tag. This allows for granular control of permissions based on the tagging of fact sheets. To learn how to use tags on fact sheets, see [Tags](https://help.sap.com/docs/leanix/ea/tags?locale=en-US&state=PRODUCTION&version=CLOUD "Tags are labels used to classify and categorize fact sheets, making it easy to filter, organize, and analyze data. Learn how to assign and manage tags, understand when and when not to use them, as well as leverage them for filtering and reporting.").
For example, consider a fact sheet tagged as Confidential. You can configure tag-based permissions so that only specific roles can read the Description field on fact sheets tagged as Confidential. This ensures that sensitive descriptions are only accessible to those with the necessary permissions.
YesNo
Send
